EI class

Constructors

EI()

Properties

hashCode int
The hash code for this object.
no setterinherited
res1 Map
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get_google_refferer() Future<void>
init() Map
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

channel → const MethodChannel